==> apache-iotdb-1.3.1-source-release.zip: apache-iotdb-1.3.1/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/storageengine/dataregion/DeviceLastFlushTime.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.storageengine.dataregion;

import java.util.HashMap;
import java.util.Map;

public class DeviceLastFlushTime implements ILastFlushTime {

  Map<String, Long> deviceLastFlushTimeMap = new HashMap<>();

  @Override
  public long getLastFlushTime(String deviceId) {
    if (deviceLastFlushTimeMap.containsKey(deviceId)) {
      return deviceLastFlushTimeMap.get(deviceId);
    }
    return Long.MIN_VALUE;
  }

  @Override
  public void updateLastFlushTime(String deviceId, long time) {
    deviceLastFlushTimeMap.merge(deviceId, time, Math::max);
  }

  @Override
  public ILastFlushTime degradeLastFlushTime() {
    long maxTime = Long.MIN_VALUE;
    for (long time : deviceLastFlushTimeMap.values()) {
      maxTime = Math.max(maxTime, time);
    }
    return new PartitionLastFlushTime(maxTime);
  }
}

==> apache-iotdb-1.3.2-source-release.zip: apache-iotdb-1.3.2/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/storageengine/dataregion/DeviceLastFlushTime.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.storageengine.dataregion;

import org.apache.iotdb.tsfile.file.metadata.IDeviceID;

import java.util.HashMap;
import java.util.Map;

public class DeviceLastFlushTime implements ILastFlushTime {

  Map<IDeviceID, Long> deviceLastFlushTimeMap = new HashMap<>();

  @Override
  public long getLastFlushTime(IDeviceID deviceId) {
    if (deviceLastFlushTimeMap.containsKey(deviceId)) {
      return deviceLastFlushTimeMap.get(deviceId);
    }
    return Long.MIN_VALUE;
  }

  @Override
  public void updateLastFlushTime(IDeviceID deviceId, long time) {
    deviceLastFlushTimeMap.merge(deviceId, time, Math::max);
  }

  @Override
  public ILastFlushTime degradeLastFlushTime() {
    long maxTime = Long.MIN_VALUE;
    for (long time : deviceLastFlushTimeMap.values()) {
      maxTime = Math.max(maxTime, time);
    }
    return new PartitionLastFlushTime(maxTime);
  }
}
